==> u_team_core-fabric-1.20.1-5.1.4.382-multiloader_testsources.jar: info/u_team/u_team_test/test_multiloader/block/TestInventoryBlock.java <==
package info.u_team.u_team_test.test_multiloader.block;

import info.u_team.u_team_core.block.UEntityBlock;
import info.u_team.u_team_test.test_multiloader.blockentity.TestInventoryBlockEntity;
import info.u_team.u_team_test.test_multiloader.init.TestMultiLoaderBlockEntityTypes;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1657;
import net.minecraft.class_1750;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2498;
import net.minecraft.class_2586;
import net.minecraft.class_2591;
import net.minecraft.class_2680;
import net.minecraft.class_2689.class_2690;
import net.minecraft.class_2741;
import net.minecraft.class_2753;
import net.minecraft.class_2766;
import net.minecraft.class_3620;
import net.minecraft.class_3965;
import net.minecraft.class_5558;

public class TestInventoryBlock extends UEntityBlock {
	
	public static final class_2753 FACING = class_2741.field_12525;
	
	public TestInventoryBlock() {
		super(class_2251.method_9637().method_31710(class_3620.field_16023).method_51368(class_2766.field_12653).method_9632(2F).method_29292().method_9626(class_2498.field_11529).method_9628(0.8F).method_9631(state -> 1), TestMultiLoaderBlockEntityTypes.TEST_INVENTORY);
		method_9590(method_9564().method_11657(FACING, class_2350.field_11043));
	}
	
	@Override
	public class_2680 method_9605(class_1750 context) {
		return method_9564().method_11657(FACING, context.method_7715().method_10153());
	}
	
	@Override
	public class_1269 method_9534(class_2680 state, class_1937 world, class_2338 pos, class_1657 player, class_1268 hand, class_3965 hit) {
		return openMenu(world, pos, player, true);
	}
	
	@Override
	protected void method_9515(class_2690<class_2248, class_2680> builder) {
		builder.method_11667(FACING);
	}
	
	@Override
	public <T extends class_2586> class_5558<T> method_31645(class_1937 level, class_2680 state, class_2591<T> type) {
		if ((type != blockEntityType.get()) || level.method_8608()) {
			return null;
		}
		return (level_, pos, state_, instance) -> TestInventoryBlockEntity.serverTick(level_, pos, state_, (TestInventoryBlockEntity) instance);
	}
	
}

==> u_team_core-fabric-1.21.1-5.6.2.364-multiloader_testsources.jar: info/u_team/u_team_test/test_multiloader/block/TestInventoryBlock.java <==
package info.u_team.u_team_test.test_multiloader.block;

import info.u_team.u_team_core.block.UEntityBlock;
import info.u_team.u_team_test.test_multiloader.blockentity.TestInventoryBlockEntity;
import info.u_team.u_team_test.test_multiloader.init.TestMultiLoaderBlockEntityTypes;
import net.minecraft.class_1269;
import net.minecraft.class_1657;
import net.minecraft.class_1750;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2498;
import net.minecraft.class_2586;
import net.minecraft.class_2591;
import net.minecraft.class_2680;
import net.minecraft.class_2689.class_2690;
import net.minecraft.class_2741;
import net.minecraft.class_2753;
import net.minecraft.class_2766;
import net.minecraft.class_3620;
import net.minecraft.class_3965;
import net.minecraft.class_5558;

public class TestInventoryBlock extends UEntityBlock {
	
	public static final class_2753 FACING = class_2741.field_12525;
	
	public TestInventoryBlock() {
		super(class_2251.method_9637().method_31710(class_3620.field_16023).method_51368(class_2766.field_12653).method_9632(2F).method_29292().method_9626(class_2498.field_11529).method_9628(0.8F).method_9631(state -> 1), TestMultiLoaderBlockEntityTypes.TEST_INVENTORY);
		method_9590(method_9564().method_11657(FACING, class_2350.field_11043));
	}
	
	@Override
	public class_2680 method_9605(class_1750 context) {
		return method_9564().method_11657(FACING, context.method_7715().method_10153());
	}
	
	@Override
	protected class_1269 method_55766(class_2680 state, class_1937 level, class_2338 pos, class_1657 player, class_3965 hitResult) {
		return openMenu(level, pos, player, true);
	}
	
	@Override
	protected void method_9515(class_2690<class_2248, class_2680> builder) {
		builder.method_11667(FACING);
	}
	
	@Override
	public <T extends class_2586> class_5558<T> method_31645(class_1937 level, class_2680 state, class_2591<T> type) {
		if ((type != blockEntityType.get()) || level.method_8608()) {
			return null;
		}
		return (level_, pos, state_, instance) -> TestInventoryBlockEntity.serverTick(level_, pos, state_, (TestInventoryBlockEntity) instance);
	}
	
}
